% !TeX root = main.tex
%%==============================================================================
%%                            WZL LaTex Class
%%                                 V2.0
%%             Dissertations, project reports, bachelor theses, master theses
%%
%%------------------------------------------------------------------------------
%%
%% Class developed by:
%%
%% Amon Göppert (gpp)
%% Laboratory for Machine Tools and Production Engineering WZL | RWTH Aachen
%% Chair of Production Metrology and Quality Management
%% Department Model-based Systems
%% Group Metrology Assisted Assembly
%%
%% Production Engineering Cluster
%% Campus-Boulevard 30, 52074 Aachen | GERMANY
%% Phone: +49 241 80-20599
%% mailto: a.goeppert@wzl.rwth-aachen.de
%%
%%
%%------------------------------------------------------------------------------
%%
%% Aachen, October 2019
%% based on LaTeX `book.cls'
%% This specific file is the class file, which is needs to be specified in the command \documentclass{}
%%
%------------------------------------------------------------------
%%
%%
%% Class edited by:
%%
%% Tobias Hamann (hmt)
%% Group Leader
%% 
%% Laboratory for Machine Tools and Production 
%% Engineering WZL of RWTH Aachen
%% Chair of Production Metrology and Quality Management
%% Department for Organizational Development | Industrial Capabilities
%% Production Engineering Cluster
%% Campus-Boulevard 30
%% 52074 Aachen | GERMANY
%% Phone: +49 151 72921981
%% mailto: t.hamann@wzl-mq.rwth-aachen.de
%%
%%
%%------------------------------------------------------------------------------
%%
%% Aachen, May 2022
%% Changed the file to be working with MiKTeX, TexStudio and Citavi 6 on a local machine rather than on an online plattform. Also cleaned up the code from development artifacts and added comments for understanding.
%%
%%
%------------------------------------------------------------------
%%
%%
%% Class edited by:
%%
%% Mark Sanders (sdr)
%% 
%% Laboratory for Machine Tools and Production 
%% Engineering WZL of RWTH Aachen
%% Chair of Production Metrology and Quality Management
%% Department for Organizational Development | Industrial Capabilities
%% Production Engineering Cluster
%% Campus-Boulevard 30
%% 52074 Aachen | GERMANY
%% Phone: 
%% mailto: 
%%
%%
%%------------------------------------------------------------------------------
%%
%% Aachen, 
%% 
%%

%==============================================================================
%%
%------------------------------------------------------------------
%%
%%
%% Class edited by: Mark Sanders and Tobias Hamann
%%------------------------------------------------------------------------------
%%
%% Aachen, Feburary 2025
%% Complete Rework and merging of previous works to create a common template.
%% What else can we say except you're welcome!
%%

%==============================================================================

%% ====== Class commands ======
\NeedsTeXFormat{LaTeX2e}
% \ProvidesClass{WZLtemplate}[2019/08/15 Example LaTeX class]
\ProvidesClass{format/WZLTemplate}[WZL Thesis]



%%----OPTIONS----

%% 'sans' option
\DeclareOption{sans}{
	\renewcommand{\familydefault}{\sfdefault}	
}

%% 'de' option
\DeclareOption{de}{
	\newcommand{\longlang}{ngerman}
	\newcommand{\shortlang}{de}
    \newcommand{\tmpacronymname}{Abkürzungsverzeichnis}
    \newcommand{\tmpreferencename}{Literaturverzeichnis}
    \newcommand{\tmpsymbolname}{Symbolverzeichnis}
    \newcommand{\tmpglossaryname}{Glossar}
    \PassOptionsToPackage{ngerman}{babel}
    \newcommand{\Autoref}[1]{{\autoref{#1}}}
}


%% 'en' option
\DeclareOption{en}{
	\newcommand{\longlang}{english}
	\newcommand{\shortlang}{en}
    \newcommand{\tmpacronymname}{Table of Acronyms}
    \newcommand{\tmpreferencename}{References}
    \newcommand{\tmpsymbolname}{List of Symbols}
    \newcommand{\tmpglossaryname}{Glossary}
    \PassOptionsToPackage{english}{babel}
    \AtBeginDocument{
        \renewcommand{\figureautorefname}{figure} % is otherwise capitalized
        \renewcommand{\subfigureautorefname}{figure}
        % \renewcommand{\subsubsectionautorefname}{section}
    }
    \newcommand{\Autoref}[1]{\capitalisewords{\autoref{#1}}}
}



%%----PROCESSING OPTIONS----

%% Declare, where language specific documents can be found, such as frontmatter etc. The path corresponds to the short name of the language choosen via the language option.
\def\input@path{{format/\shortlang/}}

\def\usefiramath{0}
\DeclareOption{usefiramath}{\def\usefiramath{1}}

\def\papersize{4}
\DeclareOption{a5paper}{\def\papersize{5}}
\DeclareOption{a4paper}{\def\papersize{4}}

%% Pass all unrecognized options to the base class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}

% Process all given options
\ProcessOptions\relax



%%----SET DOCUMENT PROPERTIES----

% Declares the document as a twosided report document
% The WZL Template is based on the report document template
\LoadClass[twoside]{report}

% Choose spell check language based on language option
\RequirePackage[\longlang]{babel}

%% Input encoding (enabling special characters)
\RequirePackage[utf8]{inputenc}

%% Font encoding (specifically for fonts), makes umlauts (yes this is a real english word) searchable in the final PDF file
\RequirePackage[T1]{fontenc}

%% Font type: Latin modern
\RequirePackage{lmodern}

%% Set page geometry
\ifnum\papersize=5
    \RequirePackage[
        % showframe,
        a5paper,
        left=2cm,
        right=2cm,
        top=2cm,
	bottom=2cm
    ]
    {geometry}
\else
    \RequirePackage[
        % showframe,
        a4paper,
		left=2.5cm,
		right=2.5cm,
		top=2.5cm,
		bottom=2cm
	]
	{geometry}

\fi
\RequirePackage{xcolor}
\input{format/rwthcolors/LaTeX/rwthcolors}
%% Context sensitive quoting
\RequirePackage{csquotes}

%% Standard math packages
\RequirePackage[intlimits]{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}

%% Enable bold font within math environments
\RequirePackage{bm}

%% Package for creating listing with \enumerate
\RequirePackage{enumerate}

%% Adjust line spacing
\linespread{1.5}

%% Header configurations:
%% Odd pages:
%%     left chapter name; right page number
%% Even pages:
%%     left page number; right section name
%% If no section is defined, the chapter name
%% is placed on even pages as well with markboth{}
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\fancyhf{}
\renewcommand{\chaptermark}[1]{\markboth{\thechapter\ #1}{\thechapter\ #1}}
\renewcommand{\sectionmark}[1]{\markright{\thesection\ #1}}
\addtolength{\headheight}{\baselineskip}

\lhead[\fancyplain{}{\bfseries\thepage}]{\fancyplain{}{\bfseries\nouppercase\leftmark}}
\rhead[\fancyplain{}{\bfseries\nouppercase\rightmark}]{\fancyplain{}{\bfseries\thepage}}

%% To overwrite plain style evoked by chapter to get headers on pages where chapters start
\RequirePackage{etoolbox}
\patchcmd{\chapter}{\thispagestyle{plain}}{\thispagestyle{fancy}}{}{}

%% Adjust spacings and formats of titles, sections, etc:
%% \titlespacing*{<command>}{<left>}{<before>}{<after>}[<right>]
\RequirePackage[bf]{titlesec}
\titlespacing*{\chapter}{0pt}{-30pt}{0pt}
\titlespacing*{\section}{0pt}{11pt}{0pt}
\titlespacing*{\subsection}{0pt}{6pt}{0pt}
\titleformat{\paragraph}{\normalfont\normalsize\bfseries}{\theparagraph}{0em}{}
\titlespacing*{\paragraph}{0pt}{11pt}{0pt}
\titleformat{\chapter}{\normalfont\huge\bfseries\raggedright}{\thechapter}{1em}{} 

%% Avoid inserting blank pages for making sure that a new chapter starts on an odd page
\renewcommand{\cleardoublepage}{\clearpage}

%% Set distance after paragraph
\setlength{\parskip}{8pt}

%% Remove indentation of footnotes
\usepackage[
    hang,
    flushmargin,
    ]{footmisc} 

%% Make links, cites, toc, etc. clickable
%% Adjust colors if desired
\RequirePackage[colorlinks=false,
linkcolor=black,
citecolor=black
]{hyperref}\RequirePackage{hyperref}
\renewcommand{\theHchapter}{\arabic{chapter}\thechapter}

%% Add acronyms
%TODO comment nolist
\RequirePackage[
	printonlyused,
	%			withpage,
	%			smaller,
				nohyperlinks,
	% nolist
	]{acronym}
	
%%----IMPORT USEFULL PACKAGES----

%% Required for including any kind of graphical images
\RequirePackage{graphicx}

%% For absolute placement of figures and creation of vector graphics
\RequirePackage{tikz}
\usetikzlibrary{calc}

%% Strict placement of figures, tables, etc. referring to the tex source code
%% Usage: \begin{figure}[H]
\RequirePackage{float}

%% Alternative style of tables
\RequirePackage{booktabs}

%% Advanced table package for use-defined width definitions
\RequirePackage{tabularx}

%% Defines a \FloatBarrier command, beyond which floats may not pass; useful, for example, to ensure all floats for a section appear before the next \section command. 
\RequirePackage[section]{placeins}

%% Placing captions within figure or table environments
%% Usage: \caption{Place your caption here.}
\RequirePackage{caption}

% Setting up cations for figures
\captionsetup[figure]{
	labelfont=bf,
	justification=raggedright,
	singlelinecheck=false
}
%TODO 

% Setting up cations for tables
\captionsetup[table]{
	labelfont=bf,
	justification=raggedright,
	singlelinecheck=false
}

%% Subliminal refinements towards typographical perfection 
\RequirePackage{microtype}

%% Insert current date and time
\usepackage{datetime}
\newdateformat{verbosedate}{\the\day. \monthname[\THEMONTH] \THEYEAR}

%% For inserting external PDFs
\RequirePackage{pdfpages}

%% For inserting tabulator environments
\RequirePackage{Tabbing}

% Package to create a dummy text with \blindtext
\usepackage{blindtext}



%%----SET UP CUSTOM COLORS----



%%----SET UP TODO COMMANDS----

%% Use \todo{} for inline-todo notes
\RequirePackage[textwidth=20mm]{todonotes}
% \RequirePackage{regexpatch} % PROBLEM
\makeatletter
%\regexpatchcmd{\@todo}{\setkeys{todonotes}{#1}}{\setkeys{todonotes}{inline,#1}}{}{} % PROBLEM
\makeatother

%%----SET UP TABLE OF CONTENTS----

%% Placement of table of contents, list of figures and list of tables
\RequirePackage[titles]{tocloft}
\renewcommand{\cfttoctitlefont}{}

%% Style for tableofcontents
\setlength{\cftbeforesecskip}{5pt}



%%----SET UP BIBLIOGRAPHY----

%% bibliography for defining macros in .tex-documents
%% processing backend: bibtex
%% further explanations: https://tex.stackexchange.com/a/299286
\RequirePackage[
	backend=biber,
	style=alphabetic,
	maxalphanames=1,
	isbn=true,
	url=false,
	giveninits=true,
	maxnames=10,
	%firstinits=true
	]{biblatex}
	
%% WZL citation style: 4 capital letters & short year
\DeclareLabelalphaTemplate{
	\labelelement{
		\field[final]{shorthand}
		\field{label}
		\field[strwidth=4,strside=left,uppercase=true]{labelname}
	}
	\labelelement{
		\field[strwidth=2,strside=right]{year}
	}
}

%% Bibliograph tweak: remove "+"-sign as an abbrevation for et. al
\renewcommand*{\labelalphaothers}{}

%% Avoid overfull hbox in bibliography
\emergencystretch=1em

%% No identation when a new paragraph starts
\setlength{\parindent}{0pt}

%% Sans serif font (comparable with Arial)
%\renewcommand{\familydefault}{\sfdefault}


%% @deprecated (reason=idx files not used)
% \makeindex



%%----SET UP TABLE OF CONTENTS----


%%----SET UP LIST OF FIGURES & LIST OF TABLES----

%% LOFLOT - List of figures & list of tables
\newcommand{\loflot}{
	%% List of figures
	\stepcounter{romancounter}
	\let\tmplistfigurename\listfigurename
	\renewcommand{\listfigurename}{\Roman{romancounter}\hspace{1em}\tmplistfigurename}
	\cleardoublepage\phantomsection\addcontentsline{toc}{chapter}{\listfigurename}
	\listoffigures
	\newpage
	%% List of tables
	\stepcounter{romancounter}
	\let\tmplisttablename\listtablename
	\renewcommand{\listtablename}{\Roman{romancounter}\hspace{1em}\tmplisttablename}
	\cleardoublepage\phantomsection\addcontentsline{toc}{chapter}{\listtablename}
	\listoftables
	\newpage
	
	%% Start of main text
	\pagenumbering{arabic}
	\setcounter{page}{1}
	\setcounter{chapter}{0}
	\renewcommand{\thechapter}{\arabic{chapter}}
	
}


%%----MISCELLANEOUS----

%% Reduce error messages for horz. & vert. overstretching of text
\hbadness=10001
\vbadness=10001







%%----END OF FILE----

\endinput
%%----END OF FILE----